﻿//------------------------------------------------------------------------------
//
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
//------------------------------------------------------------------------------

using System;

namespace Microsoft.IdentityModel.Xml
{
    /// <summary>
    /// The RSAKeyValue found inside of the KeyValue element.
    /// </summary>
    public class RSAKeyValue
    {
        /// <summary>
        /// The modulus of the RSAKeyValue.
        /// </summary>
        public string Modulus { get; }

        /// <summary>
        /// The exponent of the RSAKeyValue.
        /// </summary>
        public string Exponent { get; }

        /// <summary>
        /// Creates an RSAKeyValue using the specified modulus and exponent.
        /// </summary>
        public RSAKeyValue(string modulus, string exponent)
        {
            Modulus = modulus;
            Exponent = exponent;
        }

        /// <summary>
        /// Compares two RSAKeyValue objects.
        /// </summary>
        public override bool Equals(object obj)
        {
            var other = obj as RSAKeyValue;
            if (other == null)
                return false;
            else if (string.Compare(Modulus, other.Modulus, StringComparison.OrdinalIgnoreCase) != 0
                || string.Compare(Exponent, other.Exponent, StringComparison.OrdinalIgnoreCase) != 0)
                    return false;
            return true;
        }

        /// <summary>
        /// Serves as a hash function for RSAKeyValue.
        /// </summary>
        public override int GetHashCode()
        {
            return base.GetHashCode();
        }

    }
}
